@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.040002";
+$VERSION = "5.042000";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.40.2) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.42.0) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.40.2
-    or die sprintf "%s: Perl lib version (5.40.2) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.42.0
+    or die sprintf "%s: Perl lib version (5.42.0) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -84,9 +84,9 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/usr/lib64/perl5/5.40/aarch64-linux',
+    archlibexp => '/usr/lib64/perl5/5.42/aarch64-linux',
     archname => 'aarch64-linux',
-    cc => 'clang',
+    cc => 'aarch64-unknown-linux-gnu-gcc',
     d_readlink => 'define',
     d_symlink => 'define',
     dlext => 'so',
@@ -96,16 +96,16 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib64 /lib64 /usr/lib64 /usr/lib/clang/19/lib /usr/lib',
+    libpth => '/usr/local/lib64 /lib64 /usr/lib64 /usr/lib',
     osname => 'linux',
-    osvers => '6.12.23-gentoo-dist',
+    osvers => '6.12.25-v8-16k+',
     path_sep => ':',
-    privlibexp => '/usr/lib64/perl5/5.40',
+    privlibexp => '/usr/lib64/perl5/5.42',
     scriptdir => '/usr/bin',
-    sitearchexp => '/usr/local/lib64/perl5/5.40/aarch64-linux',
-    sitelibexp => '/usr/local/lib64/perl5/5.40',
+    sitearchexp => '/usr/local/lib64/perl5/5.42/aarch64-linux',
+    sitelibexp => '/usr/local/lib64/perl5/5.42',
     so => 'so',
     useithreads => undef,
     usevendorprefix => 'define',
-    version => '5.40.2',
+    version => '5.42.0',
 };
